aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/core/lib/iomgr/resource_quota.h
diff options
context:
space:
mode:
authorGravatar Sree Kuchibhotla <sreek@google.com>2018-08-06 10:59:17 -0700
committerGravatar Sree Kuchibhotla <sreek@google.com>2018-08-06 10:59:17 -0700
commit42c5fb98f6073101c9d25923d61f5bb745611071 (patch)
tree11160d86db3f1a885ade324a431307e32ec7a94b /src/core/lib/iomgr/resource_quota.h
parenta21ab01420e6eb2eea7b96f4ebf15227befd4111 (diff)
change thd_count to thread_count
Diffstat (limited to 'src/core/lib/iomgr/resource_quota.h')
-rw-r--r--src/core/lib/iomgr/resource_quota.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/core/lib/iomgr/resource_quota.h b/src/core/lib/iomgr/resource_quota.h
index 1d5e95e04a..7b0ed7417a 100644
--- a/src/core/lib/iomgr/resource_quota.h
+++ b/src/core/lib/iomgr/resource_quota.h
@@ -93,12 +93,12 @@ void grpc_resource_user_ref(grpc_resource_user* resource_user);
void grpc_resource_user_unref(grpc_resource_user* resource_user);
void grpc_resource_user_shutdown(grpc_resource_user* resource_user);
/* Attempts to get quota (from the resource_user) to create 'thd_count' number
* of threads. Returns true if successful (i.e the caller is now free to create
* 'thd_count' number of threads) or false if quota is not available */
bool grpc_resource_user_allocate_threads(grpc_resource_user* resource_user,
- int thd_count);
-/* Releases 'thd_count' worth of quota back to the resource user. The quota
+ int thread_count);
+/* Releases 'thread_count' worth of quota back to the resource user. The quota
* should have been previously obtained successfully by calling
* grpc_resource_user_allocate_threads().
*
@@ -107,7 +107,7 @@ bool grpc_resource_user_allocate_threads(grpc_resource_user* resource_user,
* calls. The only requirement is that the number of threads allocated should
* all be eventually released */
void grpc_resource_user_free_threads(grpc_resource_user* resource_user,
- int thd_count);
+ int thread_count);
/* Allocate from the resource user (and its quota).
If optional_on_done is NULL, then allocate immediately. This may push the
@@ -93,12 +93,12 @@ void grpc_resource_user_ref(grpc_resource_user* resource_user);
void grpc_resource_user_unref(grpc_resource_user* resource_user);
void grpc_resource_user_shutdown(grpc_resource_user* resource_user);
-/* Attempts to get quota (from the resource_user) to create 'thd_count' number
+/* Attempts to get quota from the resource_user to create 'thread_count' number
* of threads. Returns true if successful (i.e the caller is now free to create
@@ -93,12 +93,12 @@ void grpc_resource_user_ref(grpc_resource_user* resource_user);
* of threads. Returns true if successful (i.e the caller is now free to create
- * 'thd_count' number of threads) or false if quota is not available */
+ * 'thread_count' number of threads) or false if quota is not available */
bool grpc_resource_user_allocate_threads(grpc_resource_user* resource_user,